/* context.h - Internal used contexts
 *  Copyright (C) 2001, 2002 Timo Schulz <ts@winpt.org>
 *  
 * This file is part of Gnuzza.
 *  
 * Gnuzza is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 *  
 * Gnuzza is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *  
 * You should have received a copy of the GNU General Public License 
 * along with Gnuzza; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */ 

#ifndef GNUZZA_CONTEXT_H
#define GNUZZA_CONTEXT_H

#define MAX_MSG_SIZE 1024
#define MAX_PKT_SIZE 8192

struct dh_state_s {
  int bits;
  MPI g;
  MPI p;
  MPI xy;
  MPI XY;
  MPI skey;
  unsigned char cipher_prefs[5];
  int ncipher;	
  unsigned short prime_prefs[5];
  int nprimes;
};
typedef struct dh_state_s *DH_STATE;

typedef struct {
    GCRY_MPI p;
    GCRY_MPI q;
    GCRY_MPI g;
    GCRY_MPI y;
    GCRY_MPI x;
    unsigned long keyid;
    unsigned long timestamp;
    unsigned secret:1;
    unsigned char *blob;
    size_t blen;
    char *id;
} public_key_s;

struct chat_ctx_s {
    GCRY_CIPHER_HD srv;
    GCRY_CIPHER_HD cli;
    unsigned is_server:1;
    char addr[128];
    int cipher_algo;
    int cipher_mode;
    char peer[128];
    char *nick;
    char *r_nick;
    int color;
    int r_color;
    DH_STATE dh;
    unsigned long seqno;
    public_key_s *pk; /* NULL = no public key auth */
    GCRY_CIPHER_HD srv_ftp;
    GCRY_CIPHER_HD cli_ftp;
};
typedef struct chat_ctx_s *CHAT_ctx;

typedef struct {
    int len;
    unsigned char d[MAX_PKT_SIZE];  
} bstring_struct;

typedef struct {
    char *handle;
    FILE *fp;
    unsigned is_used:1;  
} handle_struct;

typedef struct {
    int hfd;
    unsigned long id;
    GCRY_CIPHER_HD cli;
    GCRY_CIPHER_HD srv;
    unsigned is_server;  
} conn_struct;

struct sftp_s {
    int init;
    int cmd;
    char *file;
#ifdef __MINGW32__
    HANDLE hd;
    HANDLE serv_hd;
#else
    pthread_t hd;
    pthread_t serv_hd;
#endif
    conn_struct conn;
};

struct thread_s {
    CHAT_ctx chat;
    int sock;
    int serv;
#ifdef __MINGW32__
    HANDLE thread_hd;
#else
    pthread_t thread_hd;
#endif
    struct sftp_s sftp;
};

typedef struct thread_s *THREAD;

typedef struct {
    unsigned char type;
    unsigned char data[1024];
    size_t data_size;
    size_t n;
    int use_mdc;
    unsigned char mdc[20];  
} packet_s;

#endif /* GNUZZA_CONTEXT_H */












