/* crypto.h - Crypto routines
 *  Copyright (C) 2001, 2002 Timo Schulz <ts@winpt.org>
 *  
 * This file is part of Gnuzza.
 *  
 * Gnuzza is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * Gnuzza is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *  
 * You should have received a copy of the GNU General Public License 
 * along with Gnuzza; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */ 

#ifndef GNUZZA_CRYPTO_H
#define GNUZZA_CRYPTO_H

enum {
    PACKET_AUTH = 1,
    PACKET_MPI = 2,
    PACKET_DATA = 3,
    PACKET_PLAIN = 4,
    PACKET_FILE = 5
};

enum {
    SIG_OK = 0,
    SIG_BAD = 1,
    SIG_NOKEY = 2
};

/*-- dh-keyex.c --*/
int dh_new( DH_STATE *c );
void dh_release( DH_STATE c );
void dh_mpi_release( GCRY_MPI *ret_mpi );
void dh_delete_secrets( DH_STATE c );
int dh_init( DH_STATE *c, int bits );
int dh_handshake( DH_STATE dh, CHAT_ctx c, int sock_fd );
int dh_set_cipher_prefs( DH_STATE c, ... );
int dh_set_prime_prefs( DH_STATE c, ... );
int dh_get_cipher_id( const char *algo );
const char* dh_get_cipher_name( int id );

/*-- keyfile.c --*/
void pubkey_release( public_key_s *key );
int pubkey_get_byname( const char *file, const char *nick,
                       public_key_s **ret_key );
char* pubkey_get_fingerprint( public_key_s *key, unsigned char *fprbuf,
                              int set );
int seckey_load( public_key_s *pk, const char *file );
int pubkey_convert( const char *file, int sec, const char *nick,  char *pass );
int pubkey_list( const char *file );

/*-- packet.c --*/
int pk_sign( public_key_s *pk, const unsigned char *md, size_t mdlen,
             unsigned char *ret_r, unsigned char *ret_s );
int pk_verify( public_key_s *pk, const unsigned char *r,
               const unsigned char *s,
               const unsigned char *md, size_t mdlen );

int read_packet( CHAT_ctx c, packet_s *pkt, int fd, size_t *r_nread );
int write_packet( CHAT_ctx c, packet_s *pkt, int fd, size_t *r_nwritten );
int chat_write_msg( CHAT_ctx c, int fd, const void *buf, size_t buflen,
                    size_t *r_nwritten );
int chat_write( CHAT_ctx c, int type, int fd, const void *buf,
                size_t buflen, size_t *r_nwritten );
int chat_read_msg( CHAT_ctx c, int fd, void *buf, size_t buflen,
                   size_t *r_nread );
int chat_read( CHAT_ctx c, int *type, int fd, void *buf, size_t buflen,
               size_t *r_nread );

/*-- context.c --*/
void chat_cipher_close( GCRY_CIPHER_HD *hd );

#endif /* GNUZZA_CRYPTO_H */
