/* errors.c - Error handling.
 *  Copyright (C) 2001, 2002 Timo Schulz <ts@winpt.org>
 * 
 * This file is part of Gnuzza.
 * 
 * Gnuzza is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 * 
 * Gnuzza is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 * 
 * You should have received a copy of the GNU General Public License 
 * along with Gnuzza; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifdef HAVE_CONFIG_H
 #include <config.h>
#endif
#ifdef __MINGW32__
 #include <windows.h>
#endif
#include <unistd.h>
#include <errno.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <ncurses.h>
#include <gcrypt.h>

#include "errors.h"
#include "context.h"
#include "gnuzza.h"

int cc_errno = 0;

const char* sock_strerror(int ec); /*-- {posix,w32}-socket.c --*/

const char*
cc_strerror( int err )
{
    static char buf[128];

    if ( err == -1 )
        err = cc_errno;
    switch ( err ) {
    case CCERR_SUCCESS: return "operation was successful";
    case CCERR_GENERAL: return "general error";
    case CCERR_IDENT: return "identification failed";
    case CCERR_AUTH: return "authentifiation failed";
    case CCERR_DHKEX: return "dh handshake failed";
    case CCERR_MPI: return "error while MPI operation";
    case CCERR_GCRYPT: return gcry_strerror(-1);
    case CCERR_MDC: return "packet data was modified!";
    case CCERR_SEND_FILE: return "can't send file";
    case CCERR_RECV_FILE: return "can't receive file";
    case CCERR_SOCK: return sock_strerror(errno);
    case CCERR_PACKET: return "packet was corrupted";
    case CCERR_INV_VALUE: return "invalid value";
    case CCERR_MEMORY: return "out of core!";
    case CCERR_CONNECT: return "connection error";
    case CCERR_BASE64: return "base64 armor corrupted";
    case CCERR_NOKEY: return "no key was found";
    case CCERR_PASS: return "invalid passphrase";
    case CCERR_FILE: return strerror( errno );
    default: sprintf(buf, "errno=%d",  err ); return buf;		
    }
} /* cc_strerror */

void
sock_error( const char *info )
{
#ifndef __MINGW32__
    const char *s = sock_strerror( errno );
#else /* WIN32 */
    const char *s = sock_strerror( WSAGetLastError() );
#endif
    wprintw( msg, "SOCKET: %s: %s\n", info, s );
    wrefresh( msg );
} /* sock_error */

int
set_lasterr( int err )
{
    cc_errno = err;
    return err;
} /* set_lasterr */






