/* gnuzza.h - Gnuzza  
 *    Copyright (C) 2001, 2002 Timo Schulz <ts@winpt.org>
 *  
 * This file is part of Gnuzza.
 *  
 * Gnuzza is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 *  
 * Gnuzza is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *  
 * You should have received a copy of the GNU General Public License 
 * along with Gnuzza; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */ 

#ifndef GNUZZA_H
#define GNUZZA_H

#ifdef __MINGW32__
 #define sleep(seconds) Sleep( (seconds) * 1000 )
 #define line_len 2
 #define DIRSEP_S "\\"
 #define DIRSEP_C '\\'
#else
 #define line_len 1
 #define DIRSEP_S "/"
 #define DIRSEP_C '/'
#endif

enum {
    WHITE = 1,
    RED = 2,
    GREEN = 3,
    BLUE = 4,
    YELLOW = 5,
    CYAN = 6
};

/*-- screen.c --*/
extern WINDOW *msg;
extern WINDOW *inp;

int create_main_wnds( void );
void init_colors( void );

int tty_init_con( void );
void tty_deinit_con( void );
int tty_read_passphrase( char *pass, size_t plen, int mode );

/* These options can be used in the options file */
extern char* argval_out;
extern char* argval_bits;
extern char* argval_algo;
extern char* argval_nick;
extern char* argval_color;

/*-- context.c --*/
int chat_new( CHAT_ctx *c );
void chat_release( CHAT_ctx c );
int chat_init( CHAT_ctx *c, int server, int cipher_type );
void chat_set_server_flag( CHAT_ctx c, int yes );
int chat_set_nick( CHAT_ctx c, const char *nick, int get );
void chat_set_addr( CHAT_ctx c, const char *addr );
void chat_set_cipher( CHAT_ctx c, int algo );
void chat_set_cipher_mode( CHAT_ctx c, int mode );
void chat_set_colors( CHAT_ctx c, int local, int peer );

int chat_pk_init( CHAT_ctx c, public_key_s *pk );

int chat_dh_init( CHAT_ctx c, int bits );
int chat_dh_handshake( CHAT_ctx c, int sock );
void chat_dh_delete_secrets( CHAT_ctx c );

/*-- auth.c --*/
int chat_auth_init( CHAT_ctx c, int sock_fd );

/*-- main.c --*/
int main_loop( CHAT_ctx ctx );

/*-- config.c --*/
int home_dir_create( void );
void config_file_parse( void );
char* key_file_get( const char *name );

#if 0 /* debug */
void hexdump( const unsigned char *buf, size_t buflen );
#endif

#endif /* GNUZZA_H */

