/* posix-socket.c - POSIX socket handling.
 *  Copyright (C) 2001, 2002 Timo Schulz <ts@winpt.org>
 *  
 * This file is part of Gnuzza.
 *  
 * Gnuzza is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 *  
 * Gnuzza is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *  
 * You should have received a copy of the GNU General Public License 
 * along with Gnuzza; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */ 

#ifdef HAVE_CONFIG_H
 #include <config.h>
#endif
#ifndef __MINGW32__
#include <unistd.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>

int
sock_read( int fd, void *buf, size_t count )
{
    int nread = 0;
	
    do {
        nread = read( fd, buf, count );
    } while ( nread == -1 && errno == EINTR );
	
    return nread;
} /* sock_read */

int
sock_write( int fd, const void *buf, size_t count )
{
    int nwritten = 0;
	
    do {
        nwritten = write( fd, buf, count );
    } while ( nwritten == -1 && errno == EINTR );
	
    return nwritten;
} /* sock_write */

int
sock_close( int fd )
{
    return close( fd );
} /* sock_close */

void
sock_init( void )
{
    /* dummy to let the socket interface work. */
} /* sock_init */

void
sock_deinit( void )
{
    /* dummy to let the socket interface work. */
} /* sock_deinit */

const char*
sock_strerror( int ec )
{
    return strerror( ec );
} /* sock_strerror */
#endif

