/* sftp.h - Secure file transfer
 *   Copyright (C) 2002 Timo Schulz <ts@winpt.org>
 *
 * This file is part of Gnuzza.
 *
 * Gnuzza is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Gnuzza is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Gnuzza; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef GNUZZA_SFTP_H
#define GNUZZA_SFTP_H

#ifndef MIN
#define MIN(a,b) (((a)<(b))?(a):(b))
#endif

#define SFTP_PROTO_VERSION 3

#define SSH_FXP_INIT                1
#define SSH_FXP_VERSION             2
#define SSH_FXP_OPEN                3
#define SSH_FXP_CLOSE               4
#define SSH_FXP_WRITE               6
#define SSH_FXP_STATUS            101
#define SSH_FXP_HANDLE            102

/* file flags */
#define SSH_FXF_CREAT           0x00000008

/* error codes */
#define SSH_FX_OK                            0
#define SSH_FX_EOF                           1
#define SSH_FX_NO_SUCH_FILE                  2
#define SSH_FX_PERMISSION_DENIED             3
#define SSH_FX_FAILURE                       4
#define SSH_FX_BAD_MESSAGE                   5
#define SSH_FX_NO_CONNECTION                 6
#define SSH_FX_CONNECTION_LOST               7
#define SSH_FX_OP_UNSUPPORTED                8

enum {
    /* < 0 to avoid collisions between the SSH error codes */
    SFTP_ERR_MEM = -1000,
    SFTP_ERR_PKT = -1001,
    SFTP_ERR_READ = -1002,
    SFTP_ERR_WRITE = -1003,
    SFTP_ERR_OPEN = -1004,
    SFTP_ERR_CLOSE = -1005,
    SFTP_ERR_HANDLE = -1006,
    SFTP_ERR_PROTO = -1007,
};

/*-- high-level API */
int sftp_send_file( struct sftp_s *ftp,const char *local, const char *remote );

/*-- control API */
const char* sftp_strerror( int ec );
int sftp_proc_packets( struct sftp_s *ftp, void (*cb)( const char *text ) );
void sftp_set_debug_level( int level );
void sftp_set_debug_file( const char *file );

#endif /*GNUZZA_SFTP_H*/

