/* w32-socket.c - W32 specific socket operations.  
 *   Copyright (C) 2001, 2002 Timo Schulz <ts@winpt.org>
 *  
 * This file is part of Gnuzza.
 *  
 * Gnuzza is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 *  
 * Gnuzza is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *  
 * You should have received a copy of the GNU General Public License 
 * along with Gnuzza; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */ 

#ifdef HAVE_CONFIG_H
 #include <config.h>
#endif
#ifdef __MINGW32__
#include <stdio.h>
#include <string.h>
#include <windows.h>
#include <errno.h>

#include "types.h"

int
sock_read( int fd, void *buf, size_t count )
{
    int nread = 0;

    nread = recv( fd, buf, count, 0 );
    if ( nread == -1 )
        return -1;
    return nread;
} /* sock_read */

int
sock_write( int fd, const void *buf, size_t count )
{
    int nwritten = 0;

    nwritten = send( fd, buf, count, 0 );
    if ( nwritten == -1 )
        return -1;
    return nwritten;
} /* sock_write */

int
sock_close( int fd )
{
    return closesocket( fd );
} /* sock_close */

void
sock_init( void )
{
    WSADATA wsa_data;	
    static int first_run = 1;
	
    if ( !first_run )
        return;
		
    if ( WSAStartup( 0x202, &wsa_data ) == -1 ) {
        printf( "could not initialize Windows socket library!\n" );
        exit( 1 );
    }
	
    first_run = 0;
} /* sock_init */

void
sock_deinit( void )
{
    WSACleanup( );
} /* sock_deinit */

/*
 * Shamelessly stolen from the Sylpheed W32 version.
 */
const char*
sock_strerror( int ec )
{
    static char buf[15];
    
    switch(ec) {
    case WSAEINTR           : return "intr";
    case WSAEBADF           : return "badf";
    case WSAEACCES          : return "acces";
    case WSAEFAULT          : return "fault";
    case WSAEINVAL          : return "inval";
    case WSAEMFILE          : return "mfile";
    case WSAEWOULDBLOCK     : return "wouldblock";
    case WSAEINPROGRESS     : return "inprogress";
    case WSAEALREADY        : return "already";
    case WSAENOTSOCK        : return "not a socket";
    case WSAEDESTADDRREQ    : return "destaddrreq";
    case WSAEMSGSIZE        : return "msgsize";
    case WSAEPROTOTYPE      : return "prototype";
    case WSAENOPROTOOPT     : return "noprotoopt";
    case WSAEPROTONOSUPPORT : return "protonosupport";
    case WSAESOCKTNOSUPPORT : return "socktnosupport";
    case WSAEOPNOTSUPP      : return "opnotsupp";
    case WSAEPFNOSUPPORT    : return "pfnosupport";
    case WSAEAFNOSUPPORT    : return "afnosupport";
    case WSAEADDRINUSE      : return "addrinuse";
    case WSAEADDRNOTAVAIL   : return "addrnotavail";
    case WSAENETDOWN        : return "net down";
    case WSAENETUNREACH     : return "net unreachable";
    case WSAENETRESET       : return "net reset";
    case WSAECONNABORTED    : return "conn aborted";
    case WSAECONNRESET      : return "conn reset";
    case WSAENOBUFS         : return "nobufs";
    case WSAEISCONN         : return "is connected";
    case WSAENOTCONN        : return "not connectd";
    case WSAESHUTDOWN       : return "shutdown";
    case WSAETOOMANYREFS    : return "toomanyrefs";
    case WSAETIMEDOUT       : return "timed out";
    case WSAECONNREFUSED    : return "connection refused";
    case WSAELOOP           : return "loop";
    case WSAENAMETOOLONG    : return "name too long";
    case WSAEHOSTDOWN       : return "host down";
    case WSAEHOSTUNREACH    : return "host unreachable";
    case WSAENOTEMPTY       : return "not empty";
    case WSAEPROCLIM        : return "proclim";
    case WSAEUSERS          : return "users";
    case WSAEDQUOT          : return "dquot";
    case WSAESTALE          : return "stale";
    case WSAEREMOTE         : return "remote";
    case WSASYSNOTREADY     : return "sys not ready";
    case WSAVERNOTSUPPORTED : return "ver not supported";
    case WSANOTINITIALISED  : return "not initialised";
    case WSAHOST_NOT_FOUND  : return "host not found";
    case WSATRY_AGAIN       : return "host not found (non-authoritative)";
    case WSANO_RECOVERY     : return "not recovery";
    case WSANO_DATA         : return "no data";
    default: sprintf( buf, "ec=%d", ec ); return buf;
    }
} /* socket_strerror */
#endif



